@@ -21,8 +21,8 @@
 
 #include "element.h"
 
-#include <klocale.h>
-#include <kunitconversion/converter.h>
+#include <KLocalizedString>
+#include <KUnitConversion/Converter>
 
 #include <math.h>
 
