@@ -21,8 +21,6 @@
 
 #include <QGraphicsTextItem>
 
-#include <KRandomSequence>
-
 class QSizeF;
 
 class KalziumDidyouknow : public Plasma::Applet
@@ -47,8 +45,6 @@ class KalziumDidyouknow : public Plasma::Applet
         QGraphicsTextItem *m_label1;
         Plasma::DataEngine* m_engine;
 
-        KRandomSequence * m_random;
-
         QSizeF m_size;
 };
 
