@@ -61,7 +61,7 @@ class nuclearCalculator : public QFrame
     Q_OBJECT
 
 public:
-    nuclearCalculator(QWidget * parent = nullptr);
+    explicit nuclearCalculator(QWidget * parent = nullptr);
     ~nuclearCalculator();
 
 public slots:
