@@ -25,18 +25,18 @@
 #include <isotopeparser.h>
 #include <spectrumparser.h>
 
+#include <QCoreApplication>
+#include <QDebug>
 #include <QFile>
 #include <QFileInfo>
-#include <QSvgRenderer>
-#include <QPainter>
-#include <QCoreApplication>
 #include <QGlobalStatic>
 #include <QLocale>
-#include <QDebug>
+#include <QPainter>
+#include <QStandardPaths>
+#include <QSvgRenderer>
 #include <QUrl>
 
-#include <kunitconversion/converter.h>
-#include <QStandardPaths>
+#include <KUnitConversion/Converter>
 
 struct StaticKalziumDataObject
 {
@@ -56,7 +56,7 @@ KalziumDataObject::KalziumDataObject()
     // reading elements
     ElementSaxParser * parser = new ElementSaxParser();
 
-    QFile xmlFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/elements.xml"));
+    QFile xmlFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libkdeedu/data/elements.xml")));
     QXmlInputSource source(&xmlFile);
     QXmlSimpleReader reader;
 
@@ -71,7 +71,7 @@ KalziumDataObject::KalziumDataObject()
     //read the spectra
     SpectrumParser * spectrumparser = new SpectrumParser();
 
-    QFile xmlSpFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/spectra.xml"));
+    QFile xmlSpFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libkdeedu/data/spectra.xml")));
     QXmlInputSource spsource(&xmlSpFile);
     QXmlSimpleReader sp_reader;
 
@@ -86,7 +86,7 @@ KalziumDataObject::KalziumDataObject()
     // reading isotopes
     IsotopeParser * isoparser = new IsotopeParser();
 
-    QFile xmlIsoFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "libkdeedu/data/isotopes.xml"));
+    QFile xmlIsoFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("libkdeedu/data/isotopes.xml")));
     QXmlInputSource isosource(&xmlIsoFile);
     QXmlSimpleReader isoreader;
 
@@ -196,7 +196,7 @@ void KalziumDataObject::loadIconSet()
 {
     //FIXME in case we ever get more than one theme we need
     //a settings-dialog where we can select the different iconsets...
-    const QString setname = "school";
+    const QString setname = QStringLiteral("school");
     QString pathname = QStandardPaths::locate(
         QStandardPaths::DataLocation, "data/iconsets/" + setname + '/',
         QStandardPaths::LocateDirectory);
