@@ -12,7 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KALZIUMUNITCOMBOBOX_H
@@ -24,8 +24,8 @@ class KalziumUnitCombobox : public QComboBox
 {
 
 public:
-    KalziumUnitCombobox(QWidget *parent = nullptr);
-    KalziumUnitCombobox(const QList< int > &unitList, QWidget *parent = nullptr);
+    explicit KalziumUnitCombobox(QWidget *parent = nullptr);
+    explicit KalziumUnitCombobox(const QList< int > &unitList, QWidget *parent = nullptr);
 
     void setUnitList(const QList< int > &unitList);
     int getCurrentUnitId() const;
