@@ -51,7 +51,7 @@ int main(int argc, char **argv)
                       KAboutLicense::GPL,
                       i18n("(C) 2002-2016 Carsten Niehaus & the KDE Edu Developers"),
                       QString(),
-                      QStringLiteral("http://edu.kde.org/kalzium"));
+                      QStringLiteral("https://edu.kde.org/kalzium"));
 
     about.addAuthor(i18n("Carsten Niehaus"),
                     QString(),
@@ -132,8 +132,6 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
 
     parser.addPositionalArgument(i18n("[molecule]"), i18n("Open the given molecule file"));
 
