@@ -52,7 +52,7 @@ public:
      * constructor uses setData to set the element number using the key 0. This
      * is then used by PeriodicTable to figure out which element was clicked on.
      */
-    ElementItem(KalziumElementProperty *property, int elementNumber = 0);
+    explicit ElementItem(KalziumElementProperty *property, int elementNumber = 0);
 
     /**
      * Destructor.
